# pyzjr

[![Downloads](https://static.pepy.tech/badge/dumb-menu)](https://pepy.tech/project/dumb-menu)

This is a package that has been patched for excellent third-party libraries such as opencv and pytorch.

All useful functional functions written by individuals

I will also integrate algorithms I have previously written

## Installation

https://pypi.org/project/pyzjr/

https://github.com/Auorui/pyzjr (I want stars ⭐ hhh)

## Update log

`0.0.10` Modified the position of the repair_Img function to PIC, added interactive annotations, which can be used for perspective transformation

`0.0.9` Added mini module, can perform bucket operations

`0.0.8` Can be used normally, added zmath file

`0.0.7` fix bug

`0.0.1` first release

## Upload of Library

* `python setup.py sdist`

* `twine upload dist/*`